Module prune

Module prune 

Functions

keep_latest_versions
Build a prune policy that keeps the latest count versions for each entity in a exoware-sql versioned primary-key family with a fixed-width entity key.
keep_latest_versions_utf8
Build a prune policy that keeps the latest count versions for each entity in a exoware-sql versioned primary-key family whose entity column is Utf8.