pub struct BatchWriter { /* private fields */ }Implementations
Sourceimpl BatchWriter
impl BatchWriter
pub fn insert( &mut self, table_name: &str, values: Vec<CellValue>, ) -> Result<&mut Self, String>
pub fn pending_count(&self) -> usize
Sourcepub async fn flush(&mut self) -> DataFusionResult<u64>
pub async fn flush(&mut self) -> DataFusionResult<u64>
Flush pending rows to ingest and return the post-ingest consistency token.
Sourcepub async fn flush_with_receipt(
&mut self,
) -> DataFusionResult<Option<BatchReceipt>>
pub async fn flush_with_receipt( &mut self, ) -> DataFusionResult<Option<BatchReceipt>>
Flush pending rows to ingest and return metadata for the persisted batch.
pub fn prepare_flush(&mut self) -> DataFusionResult<Option<PreparedBatch>>
pub fn stage_flush( &self, prepared: &PreparedBatch, batch: &mut StoreWriteBatch, ) -> DataFusionResult<()>
pub fn mark_flush_persisted( &self, prepared: PreparedBatch, sequence_number: u64, ) -> BatchReceipt
pub fn mark_flush_failed(&self, prepared: PreparedBatch)